Learn R Programming

syntenyPlotteR (version 1.0.0)

syntenyPlotteR-package: syntenyPlotteR: Genome Synteny Visualization

Description

Draw syntenic relationships between genome assemblies. There are 3 functions which take a tab delimited file containing alignment data for syntenic blocks between genomes to produce either a linear alignment plot, an evolution highway style plot, or a painted ideogram representing syntenic relationships. There is also a function to convert alignment data in the DESCHRAMBLER/inferCAR format to the required data structure.

Arguments

Author

Maintainer: Marta Farre m.farre-belmonte@kent.ac.uk [copyright holder]

Authors:

See Also